@@ -35,6 +35,7 @@ from splunk_add_on_ucc_framework import (
     utils,
 )
 from splunk_add_on_ucc_framework.install_python_libraries import (
+    SplunktaucclibNotFound,
     install_python_libraries,
 )
 from splunk_add_on_ucc_framework.start_alert_build import alert_build
@@ -452,6 +453,8 @@ def generate(source, config, ta_version, outputdir=None, python_binary_name="pyt
                 os.path.join(source, PARENT_DIR, "globalConfig.yaml")
             )
             is_global_config_yaml = True
+    else:
+        is_global_config_yaml = True if config.endswith(".yaml") else False
 
     logger.info(f"Cleaning out directory {outputdir}")
     shutil.rmtree(os.path.join(outputdir), ignore_errors=True)
@@ -535,7 +538,13 @@ def generate(source, config, ta_version, outputdir=None, python_binary_name="pyt
         )
         ucc_lib_target = os.path.join(outputdir, ta_name, "lib")
         logger.info(f"Install add-on requirements into {ucc_lib_target} from {source}")
-        install_python_libraries(source, ucc_lib_target, python_binary_name)
+        try:
+            install_python_libraries(
+                source, ucc_lib_target, python_binary_name, includes_ui=True
+            )
+        except SplunktaucclibNotFound as e:
+            logger.error(str(e))
+            sys.exit(1)
 
         _replace_token(ta_name, outputdir)
 
